PCB Environment: CloneEnv Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
CloneEnv Class Reference

`#include <Clone.hpp>`

## Public Member Functions
| CloneEnv (PCBoard &pcb)

## Data Fields
const PCBoard & | origin
std::map< const Component *, Component * > | C
std::map< const Pin *, Pin * > | P
std::map< const std::vector< Pin * > *, std::vector< Pin * > * > | PK
std::map< const Net *, Net * > | N
std::map< const Connection *, Connection * > | X
PCBoard * | target {0}

## Detailed Description

Helper for deep-copying a PCBoard to map old to new objects.

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Clone.hpp